table.table.cradmin-table-fluid {
  margin: 0;
  tbody tr td,
  thead tr th {
    &:first-child {
      padding-left: @cradmin-bodypadding-xs;
      @media (min-width: @screen-sm-min) {
        padding-left: @cradmin-bodypadding;
      }
    }
    &:last-child {
      padding-right: @cradmin-bodypadding-xs;
      @media (min-width: @screen-sm-min) {
        padding-right: @cradmin-bodypadding;
      }
    }
  }
  thead {
    border-bottom: 1px solid @cradmin-table-fluid-body-border-color;
    background-color: @cradmin-table-fluid-header-bg;
    tr th {
      border: none;
    }
  }
  tbody {
    background-color: @cradmin-table-fluid-body-bg;
    border-bottom: 1px solid @cradmin-table-fluid-body-border-color;
    tr {
      border-top: 1px @cradmin-table-fluid-body-rowseparator-style @cradmin-table-fluid-body-rowseparator-color;
      &:first-child {
        border-top: none;
      }
      td {
        border: none;
        padding-top: 15px;
        padding-bottom: 15px;
      }
    }
  }
}
