.django-cradmin-bulkfileupload {
  padding: @cradmin-bulkfileupload-padding;
  background: @cradmin-bulkfileupload-bg;
  .django-cradmin-bulkfileupload-dropbox {
    background-color: @cradmin-bulkfileupload-dropbox-bg;
    color: @cradmin-bulkfileupload-dropbox-color;
    font-weight: @cradmin-bulkfileupload-dropbox-font-weight;
    font-size: @cradmin-bulkfileupload-dropbox-font-size;
    padding: @cradmin-bulkfileupload-dropbox-padding;
    text-align: @cradmin-bulkfileupload-dropbox-text-align;
    border-style: @cradmin-bulkfileupload-dropbox-border-style;
    border-color: @cradmin-bulkfileupload-dropbox-border-color;
    border-width: @cradmin-bulkfileupload-dropbox-border-width;

    .django-cradmin-bulkfileupload-dropbox-invalid-filetype-errormessage {
      display: none;
    }

    &.django-cradmin-bulkfileupload-dropbox-dragover {
      background-color: @cradmin-bulkfileupload-dropbox-dragover-bg;
      color: @cradmin-bulkfileupload-dropbox-dragover-color;
      border-style: @cradmin-bulkfileupload-dropbox-dragover-border-style;
      border-color: @cradmin-bulkfileupload-dropbox-dragover-border-color;
    }
    &.django-cradmin-bulkfileupload-dropbox-dragover-error {
      background-color: @cradmin-bulkfileupload-dropbox-dragover-error-bg;
      color: @cradmin-bulkfileupload-dropbox-dragover-error-color;
      border-style: @cradmin-bulkfileupload-dropbox-dragover-error-border-style;
      border-color: @cradmin-bulkfileupload-dropbox-dragover-error-border-color;
      .django-cradmin-bulkfileupload-dropbox-invalid-filetype-errormessage {
        display: block;
      }
      .django-cradmin-bulkfileupload-dropbox-text {
        display: none;
      }
    }
  }

  p.django-cradmin-bulkfileupload-advanced-fileselectbutton-wrapper {
    text-align: @cradmin-bulkfileupload-advanced-fileselectbutton-align;
    .django-cradmin-bulkfileupload-advanced-fileselectbutton {
      display: inline-block;
      color: @cradmin-bulkfileupload-advanced-fileselectbutton-color;
      &:hover {
        color: @cradmin-bulkfileupload-advanced-fileselectbutton-hover-color;
      }
    }
  }

  p.django-cradmin-bulkfileupload-simple-button-wrapper {
    padding: @cradmin-bulkfileupload-simple-button-wrapper-padding;
    margin: 0;
    .btn.django-cradmin-bulkfileupload-simple-button {
      padding: @cradmin-bulkfileupload-simple-button-padding;
    }
  }

  .django-cradmin-bulkfileupload-progress,
  .django-cradmin-bulkfileupload-rejectedfiles {
    p.django-cradmin-bulkfileupload-progress-item,
    p.django-cradmin-bulkfileupload-rejectedfile {
      font-weight: @cradmin-bulkfileupload-progress-item-font-weight;
      font-size: @cradmin-bulkfileupload-progress-item-font-size;
      margin: @cradmin-bulkfileupload-progress-item-margin;
      padding: @cradmin-bulkfileupload-progress-item-padding-mobile;

      @media (min-width: @screen-md-min) {
        padding: @cradmin-bulkfileupload-progress-item-padding;
      }

      &.django-cradmin-bulkfileupload-errorparagraph {
        background-color: @cradmin-bulkfileupload-progress-item-error-bg;
        color: @cradmin-bulkfileupload-progress-item-error-color;

        .django-cradmin-bulkfileupload-error-closebutton {
          float: right;
          margin-top: -7px;
          margin-right: -7px;
          color: @cradmin-bulkfileupload-progress-item-error-closebutton-color;
          &:hover {
            color: @cradmin-bulkfileupload-progress-item-error-closebutton-hover-color;
          }
        }
      }
    }
  }
  .django-cradmin-bulkfileupload-progress {
    background: @cradmin-bulkfileupload-bg;
    p.django-cradmin-bulkfileupload-progress-item {
      color: @cradmin-bulkfileupload-progress-item-color;

      .django-cradmin-progressbar {
        display: inline-block;
        background-color: @cradmin-bulkfileupload-progressbar-bg;
        width: 100px;
        position: relative;
        .django-cradmin-progressbar-progress {
          display: inline-block;
          height: 100%;
          background-color: @cradmin-bulkfileupload-progressbar-progress-bg;
        }

        .django-cradmin-progresspercent {
          position: absolute;
          top: 1px;
          left: 5px;
          font-size: @cradmin-bulkfileupload-progresspercent-font-size;
          color: @cradmin-bulkfileupload-progresspercent-color;
        }
      }

      .django-cradmin-bulkfileupload-remove-file-button {
        float: right;
        margin-top: -7px;
        margin-right: -7px;
        color: @cradmin-bulkfileupload-progress-item-remove-file-button-color;
        &:hover {
          color: @cradmin-bulkfileupload-progress-item-remove-file-button-hover-color;
        }
      }
    }
  }
}

.django-cradmin-form .cradmin-focusfield .form-group .controls .django-cradmin-bulkfileupload {
//  background: @cradmin-bulkfileupload-bg;
}
