.pager-container {
  .pager {
    margin: 0;
    padding: 10px 0;
    color: #999;

    li > a,
    li > span {
      background-color: transparent;
      border: none;
      padding: 5px 14px;
    }

    li,
    li > a {
      line-height: 24px;
    }

    li > a {
      //    color: @brand-primary;
      padding: 0;

      &:hover {
        background: transparent;
        color: @link-color;
      }
    }

    li.disabled > a,
    li.disabled > a:hover,
    li.disabled > a:focus,
    li.disabled {
      color: #777777;
      background-color: transparent;
    }
  }
}
