{% extends "django_cradmin/standalone-base.django.html" %}
{% load i18n %}

{% block body %}
    <div class="container">
        <h1>{% trans "Signed out" %}</h1>

        <a href="{% url 'django_cradmin-login' %}" class="btn btn-primary">
            {% trans "Sign back in" %}
        </a>
    </div>
{% endblock body %}
