<li class="{% if menuitem.is_active %}cradmin_menu_activeitem{% endif %}">
    <a href="{{ menuitem.url }}" title="{{ menuitem.description }}">
        {% if menuitem.icon %}
            <span class="fa fa-{{ menuitem.icon }}"></span>
        {% else %}
            <span class="fa fa-dot-circle-o"></span>
        {% endif %}
        {{ menuitem.label }}
    </a>
</li>
