{% extends "django_cradmin/viewhelpers/formview_base.django.html" %}
{% load i18n %}
{% load crispy_forms_tags %}

{% block form %}
    {{ block.super }}

    {% block handle_preview %}
        {% if show_preview %}
            <div django-cradmin-page-preview-wrapper>
                {% include "django_cradmin/pagepreview/includes/pagepreview-fullsize-iframe-wrapper.django.html" %}
                <div django-cradmin-page-preview-open-on-page-load="{{ preview_url }}"></div>
            </div>
        {% endif %}
    {% endblock handle_preview %}
{% endblock form %}
