.fa-header {
    &.fa-django-cradmin-h1 {
        font-size: ceil(@font-size-base + 4px);
    }
    &.fa-django-cradmin-h2 {
        font-size: ceil(@font-size-base);
    }
    &.fa-django-cradmin-h3 {
        font-size: ceil(@font-size-base - 4px);
    }
}