{% load cradmin_image_tags %}
{% load i18n %}

<p>
    <img src="{% cradmin_thumbnail archiveimage.image width=300 height=300 %}"
         alt="{% trans 'Image preview' %}">
</p>
<p>
    {{ archiveimage.name }}
</p>
