.django-cradmin-floating-fullsize-iframe-wrapper  {
  position: fixed;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  z-index: 50000;
  background-color: rgba(30, 30, 30, 0.8);

  a.django-cradmin-floating-fullsize-iframe-closebutton  {
    position: absolute;
    top: 2px;
    right: 2px;
    text-align: center;
    font-size: 30px;
    z-index: 50001;
    width: 50px;
    line-height: 50px;
    border-radius: 25px;
    background-color: #000;
    color: #ddd;

    &:hover {
      color: #fff;
      text-decoration: none;
    }
  }

  .django-cradmin-floating-fullsize-loadspinner {
    color: #ccc;
    font-size: 50px;
    text-align: center;
    padding-top: 25px;
  }

  .django-cradmin-floating-fullsize-iframe-inner {
    overflow: auto;
    -webkit-overflow-scrolling: touch;
    position: absolute;
    top: 20px;
    bottom: 20px;
    left: 20px;
    right: 20px;
//    height: 100%;
//    width: 100%;

    iframe {
      position: absolute;
      top: 0;
      bottom: 0;
      left: 0;
      right: 0;
      height: 100%;
      width: 100%;
      border: none;
    }
  }
}
