{% extends "django_cradmin/base.django.html" %}
{% load i18n %}
{% load crispy_forms_tags %}

{% block content %}
    {% block form %}
        {% crispy form formhelper %}

        {% comment %}
            NOTE: This will probably break when https://github.com/maraujop/django-crispy-forms/issues/263 is fixed
        {% endcomment %}
        {{ form.media }}
    {% endblock form %}
{% endblock content %}
