.django-cradmin-form {
  .django_cradmin_filewidget {
    padding: 10px 15px;

    img {
      max-width: 300px;
      height: auto;
      display: block;
      margin-bottom: 10px;
    }

    a.django_cradmin_filewidget_fullviewlink {
      display: block;
      border: none;
      margin-bottom: 10px;
    }

    .django_cradmin_filewidget_field_and_overlay_wrapper {
      position: relative;

      // Style button and file field the same size
      input[type=file],
      a.django_cradmin_filewidget_fieldoverlay {
        width: 300px;
        height: 40px;
        border-radius: 3px;

      }
      &.django_cradmin_filewidget_field_and_overlay_wrapper_hover {
        a.btn.btn-default {
          .btn-default-hoverstyle-mixin();
        }
      }

      // Put the file field on top of the button, making the user click
      // the invisible file field instead of the button.
      input[type=file] {
        opacity: 0 !important;
        position: absolute;
        top: 0;
        left: 0;
        overflow: hidden !important;
        cursor: pointer;
      }
    }

    &.django_cradmin_filewidget_clearable {
      label.django_cradmin_filewidget_clear {
        font-weight: normal;
        padding: 0;
        margin: 10px 0 0 0;
        background-color: #eee;
      }
    }
  }

  .cradmin-focusfield {
    .django_cradmin_filewidget {
      .body-side-padding();
      background-color: #fff;
      padding-top: 20px;
      padding-bottom: 20px;
      @media (min-width: @screen-md-min) {
        max-width: 600px;
        border-right: 1px dashed #ccc;
      }
      @media (min-width: @screen-lg-min) {
        max-width: 800px;
      }
    }
  }
}


