{% extends "django_cradmin/standalone-base.django.html" %}
{% load crispy_forms_tags %}
{% load i18n %}
{% load staticfiles %}

{% block body %}
    <div class="container">
        <h1>{% trans "Sign in" %}</h1>

        {% crispy form form.helper %}

        <p>
{#            <a href="{% url 'django_cradmin-reset-password' %}">#}
{#                {% trans "Forgot your password?" %}#}
{#            </a>#}
        </p>
    </div>

{% endblock body %}
