{% extends "django_cradmin/base.django.html" %}
{% load i18n %}
{% load static %}

{% block content %}
    <div class="page-header">
        <div class="container-fluid">
            <span class="fa fa-home"></span>
            <h1>
                {% trans "Error" %}:
            </h1>
        </div>
    </div>
    <div class="container-fluid">
        <div class="alert alert-danger">
            {{ error }}
        </div>
    </div>
{% endblock content %}
