{% extends "django_cradmin/base.django.html" %}
{% load i18n %}

{% block pageheader-inner %}
    {% block headingicon %}
        <span class="fa fa-trash-o cradmin-page-header-icon"></span>
    {% endblock headingicon %}
    <h1>
        {% block heading %}
            <strong>{% trans "DELETE" %}</strong>
            {{ model_verbose_name }}
        {% endblock heading %}
    </h1>
{% endblock pageheader-inner %}

{% block content %}
    {% block deletequestion %}
        <div id="deleteview-preview" class="container-fluid container-focus">
            <p>{% blocktrans %}Are you sure you want to delete "{{ object_preview }}"?{% endblocktrans %}</p>
        </div>
    {% endblock deletequestion %}

    {% block delete-form %}
        <form action="{{ request.build_absolute_uri }}" method="post" class="django-cradmin-form">{% csrf_token %}
            <div class="django_cradmin_submitrow">
                <button type="submit" class="btn btn-danger">{% trans "Delete" %}</button>
                <a class="btn btn-cancel" django-cradmin-back>{% trans "Cancel" %}</a>
            </div>
        </form>
    {% endblock delete-form%}
{% endblock content %}
