{% load i18n %}
{% load cradmin_image_tags %}
{% if image_path == None %}
    <em class="text-muted">{% trans "(None)" %}</em>
{% else %}
    <img src="{% cradmin_thumbnail image_path width=preview_width height=preview_height image_format=preview_format %}">
{% endif %}
