{% extends "django_cradmin/standalone-base.django.html" %}
{% load cradmin_tags %}

{% block body %}
    {% block menu %}
        {% cradmin_render_menu %}
    {% endblock menu %}

    <div id="django_cradmin_contentwrapper">
        {% block pageheader %}
            <div class="page-header">
                <div class="container-fluid">
                    {% block pageheader-inner %}{% endblock pageheader-inner %}
                </div>
            </div>
        {% endblock pageheader %}

        {% block messages %}
            {% include "django_cradmin/include/messages.django.html" %}
        {% endblock messages %}

        {% block content %}{% endblock content %}
    </div>
{% endblock body %}
