angular.module('djangoCradmin', [
  'djangoCradmin.templates'
  'djangoCradmin.directives'
  'djangoCradmin.messages'
  'djangoCradmin.detectizr'
  'djangoCradmin.menu'
  'djangoCradmin.objecttable'
  'djangoCradmin.acemarkdown'
  'djangoCradmin.bulkfileupload'
#  'djangoCradmin.wysihtml'
  'djangoCradmin.imagepreview'
  'djangoCradmin.pagepreview'
  'djangoCradmin.forms.modelchoicefield'
  'djangoCradmin.forms.usethisbutton'
])
