{% load i18n %}
{% comment %}
    Include template used to show an embedded iframe floating above
    the page with a close button. This renders the
    ``django-cradmin-floating-fullsize-iframe-wrapper`` AngularJS directive
    components with some extra components to make it stylable and accessible.

    Example::

        <div django-cradmin-page-preview-wrapper>
            {% include "django_cradmin/pagepreview/includes/pagepreview.django.html" %}
            <div django-cradmin-page-preview-open-on-page-load="'{{ preview_url }}'"></div>
        </div>

{% endcomment %}

<div class="ng-hide django-cradmin-floating-fullsize-iframe-wrapper"
     django-cradmin-page-preview-iframe-wrapper>
    <a href="#" class="django-cradmin-floating-fullsize-iframe-closebutton"
       django-cradmin-page-preview-iframe-closebutton>
        <span class="fa fa-close"></span>
        <span class="sr-only">{% trans "Close preview" %}</span>
    </a>
    <div class="django-cradmin-floating-fullsize-loadspinner">
        <span class="fa fa-spinner fa-spin"></span>
    </div>
    <div class="django-cradmin-floating-fullsize-iframe-inner">
        <iframe django-cradmin-page-preview-iframe></iframe>
    </div>
</div>
