// Variables
@import "fontawesome/less/variables";
@fa-font-path: "../../vendor/fonts";

// All fontawesome components
@import "fontawesome/less/mixins";
@import "fontawesome/less/path";
@import "fontawesome/less/core";
@import "fontawesome/less/larger";
@import "fontawesome/less/fixed-width";
@import "fontawesome/less/list";
@import "fontawesome/less/bordered-pulled";
@import "fontawesome/less/spinning";
@import "fontawesome/less/rotated-flipped";
@import "fontawesome/less/stacked";
@import "fontawesome/less/icons";
